@@ -6,30 +6,8 @@ from rpy2.robjects import FloatVector, numpy2ri
 from datetime import datetime
 
 
-base = importr('base')
-utils = importr('utils')
-pth = os.path.abspath(os.getcwd())
-
 stats = importr('stats')
-graphics = importr('graphics')
-grdevices = importr('grDevices')
-
-try:
-    forecast = importr('forecast')
-except:
-    base.suppressWarnings(utils.install_packages("forecast",
-                                                 repos="file:///" + pth + "/r-ahead-forge",
-                                                 type="source"))
-    forecast = importr('forecast')
-
-try:
-    ahead = importr('ahead')
-except:
-    base.suppressWarnings(utils.install_packages("ahead",
-                                                 repos="file:///" + pth + "/r-ahead-forge",
-                                                 type="source"))
-    ahead = importr('ahead')
-
+ahead = importr('ahead')
 
 class EAT():
 
